pyrses
======

sounds like purses, rhymes with curses, the tui framework.


design notes to self
--------------------
**accepted**:

- use curses backend

**declined**:

- posibly use termios module instead of introducing ncurses dependancy

